<?php
// {{{ICINGA_LICENSE_HEADER}}}
/**
 * This file is part of Icinga 2 Web.
 *
 * Icinga 2 Web - Head for multiple monitoring backends.
 * Copyright (C) 2013 Icinga Development Team
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @copyright 2013 Icinga Development Team <info@icinga.org>
 * @license   http://www.gnu.org/licenses/gpl-2.0.txt GPL, version 2
 * @author    Icinga Development Team <info@icinga.org>
 */
// {{{ICINGA_LICENSE_HEADER}}}

namespace Monitoring\Form\Command;

/**
 * Form to handle DelayNotification command
 */
class DelayNotificationForm extends CommandForm
{
    /**
     * Biggest value for minutes
     */
    const MAX_VALUE = 1440;
    /**
     * Interface method to build the form
     * @see CommandForm::create
     */
    protected function create()
    {
        $this->addElement(
            'text',
            'minutes',
            array(
                'label'    => t('Notification delay'),
                'style'    => 'width: 80px;',
                'value'    => 0,
                'required' => true,
                'validators' => array(
                    array(
                        'between',
                        true,
                        array(
                            'min' => 1,
                            'max' => self::MAX_VALUE
                        )
                    )
                )
            )
        );

        $this->addNote('Delay next notification in minutes from now');

        $this->setSubmitLabel(t('Delay notification'));

        parent::create();
    }

    public function getDelayTime()
    {
        return $this->getValue('minutes')*60;
    }
}
